@@ -57,6 +57,7 @@ class RestAPI(object):
 			},
 		}
 
+
 		"""
 		The plans.
 			the "rate_limit" is total requests per "rate_reset"
@@ -401,7 +402,7 @@ class RestAPI(object):
 
 			# handle new data.
 			data = None
-			if response["error"] != None:
+			if True or response["error"] != None:
 				response = self.__save_new_user__(uid)
 				if response["error"] != None: 
 					if silent == False: print(f"Error: {response['error']}")
